summaryrefslogtreecommitdiffhomepage
path: root/pkg/abi/linux/ioctl.go
diff options
context:
space:
mode:
Diffstat (limited to 'pkg/abi/linux/ioctl.go')
-rw-r--r--pkg/abi/linux/ioctl.go10
1 files changed, 7 insertions, 3 deletions
diff --git a/pkg/abi/linux/ioctl.go b/pkg/abi/linux/ioctl.go
index 29062c97a..4526d3f95 100644
--- a/pkg/abi/linux/ioctl.go
+++ b/pkg/abi/linux/ioctl.go
@@ -180,8 +180,12 @@ var (
// to get quote.
const SizeOfQuoteInputData = 64
// SignReport is a struct that gets signed quote from input data.
type SignReport struct {
- data [64]byte
- quote []byte
+ data [64]byte
+ size uint32
+ buf []byte
}
@@ -180,8 +180,12 @@ var (
// to get quote.
const SizeOfQuoteInputData = 64
-// SignReport is a struct that gets signed quote from input data.
+// SignReport is a struct that gets signed quote from input data. The
+// serialized quote is copied to buf.
+// size is an input that specifies the size of buf. When returned, it's updated
+// to the size of quote.
type SignReport struct {